@@ -4,24 +4,27 @@ import re
 import os
 import sys
 import datetime
+import webbrowser
 
 import click
 from click_aliases import ClickAliasedGroup
 
 from twc import fmt
+from twc.click_ext import MutuallyExclusiveOption
+from twc.vars import (
+    DEFAULT_CONFIGURATOR_ID,
+    REGIONS_WITH_CONFIGURATOR,
+    REGIONS_WITH_IPV6,
+    TWC_CP_URL,
+)
 from . import (
     create_client,
     handle_request,
     options,
     debug,
-    confirm_action,
     set_value_from_config,
-    MutuallyExclusiveOption,
     GLOBAL_OPTIONS,
     OUTPUT_FORMAT_OPTION,
-    DEFAULT_CONFIGURATOR_ID,
-    REGIONS_WITH_CONFIGURATOR,
-    REGIONS_WITH_IPV6,
 )
 from .ssh_key import (
     _ssh_key_list,
@@ -30,6 +33,7 @@ from .ssh_key import (
 )
 from .image import _image_list
 from .project import (
+    get_default_project_id,
     _project_list,
     _project_resource_list_servers,
     _project_resource_move,
@@ -459,17 +463,6 @@ def get_os_id_by_name(os_images: list, os_name: str) -> int:
     return os_id
 
 
-def get_project_id_by_server_id(client, projects: list, server_id: int) -> int:
-    """Return project_id by server_id."""
-    for project in projects:
-        for server in _project_resource_list_servers(
-            client, project["id"]
-        ).json()["servers"]:
-            if server["id"] == server_id:
-                return project["id"]
-    return None
-
-
 def size_to_mb(size: str) -> int:
     """Transform string like '5G' into integer in megabytes.
     Case insensitive. For example::
@@ -733,6 +726,7 @@ def server_create(
     """Create Cloud Server."""
     # pylint: disable=too-many-locals
     # pylint: disable=too-many-branches
+    # pylint: disable=too-many-statements
 
     client = create_client(config, profile)
 
@@ -816,14 +810,14 @@ def server_create(
 
     # Add created server to project if set
     if project_id:
+        src_project = get_default_project_id(client)
+        # Make useless request to avoid API bug (409 resource_not_found)
+        _r = _project_resource_list_servers(client, src_project)
         new_server_id = response.json()["server"]["id"]
         debug(f"Add server '{new_server_id}' to project '{project_id}'")
-        old_project_id = get_project_id_by_server_id(
-            client, projects, new_server_id
-        )
         project_resp = _project_resource_move(
             client,
-            from_project=old_project_id,
+            from_project=src_project,
             to_project=project_id,
             resource_id=new_server_id,
             resource_type="server",
@@ -842,7 +836,9 @@ def server_create(
 # ------------------------------------------------------------- #
 
 
-@server.command("set-property", help="Update Cloud Server properties.")
+@server.command(
+    "set-property", aliases=["set"], help="Update Cloud Server properties."
+)
 @options(GLOBAL_OPTIONS)
 @options(OUTPUT_FORMAT_OPTION)
 @click.option("--name", help="Cloud server display name.")
@@ -1057,7 +1053,7 @@ def server_resize(
 
     # Prompt if no option --yes passed
     if not confirmed:
-        if not confirm_action("Server will restart, continue?"):
+        if not click.confirm("Server will restart. Continue?", default=False):
             sys.exit("Aborted!")
 
     # Make request
@@ -1196,6 +1192,14 @@ def server_remove(config, profile, verbose, server_ids):
 
     for server_id in server_ids:
         response = _server_remove(client, server_id)
+
+        if response.status_code == 200:
+            del_hash = response.json()["server_delete"]["hash"]
+            del_code = click.prompt("Please enter confirmation code", type=int)
+            response = _server_remove(
+                client, server_id, delete_hash=del_hash, code=del_code
+            )
+
         if response.status_code == 204:
             click.echo(server_id)
         else:
@@ -1316,10 +1320,9 @@ def print_presets(response: object, filters: str):
             "FREQ",
             "RAM",
             "DISK",
-            "DISK TYPE",
-            "BANDWIDTH",
-            "DESCRIPTION",
-            "LOCAL NETWORK",
+            "TYPE",
+            "BANDW",
+            "LAN",
         ]
     )
     for preset in presets:
@@ -1334,14 +1337,15 @@ def print_presets(response: object, filters: str):
                 str(round(preset["disk"] / 1024)) + "G",
                 preset["disk_type"],
                 preset["bandwidth"],
-                preset["description_short"],
                 preset["is_allowed_local_network"],
             ]
         )
     table.print()
 
 
-@server.command("list-presets", help="List configuration presets.")
+@server.command(
+    "list-presets", aliases=["lp"], help="List configuration presets."
+)
 @options(GLOBAL_OPTIONS)
 @options(OUTPUT_FORMAT_OPTION)
 @click.option("--region", "-r", help="Use region (location).")
@@ -1399,7 +1403,9 @@ def print_os_images(response: object, filters: str):
 
 
 @server.command(
-    "list-os-images", help="List prebuilt operating system images."
+    "list-os-images",
+    aliases=["li"],
+    help="List prebuilt operating system images.",
 )
 @options(GLOBAL_OPTIONS)
 @options(OUTPUT_FORMAT_OPTION)
@@ -1456,7 +1462,9 @@ def print_logs(response: object):
         )
 
 
-@server.command("logs", help="View Cloud Server events log.")
+@server.command(
+    "history", aliases=["logs"], help="View Cloud Server events log."
+)
 @options(GLOBAL_OPTIONS)
 @options(OUTPUT_FORMAT_OPTION)
 @click.option(
@@ -2089,11 +2097,8 @@ def print_backups(response: object):
         [
             "ID",
             "DISK",
-            "STATUS",
             "CREATED",
-            "SIZE",
-            "TYPE",
-            "COMMENT",
+            "STATUS",
         ]
     )
     for backup in backups:
@@ -2101,11 +2106,8 @@ def print_backups(response: object):
             [
                 backup["id"],
                 backup["name"],
-                backup["status"],
                 backup["created_at"],
-                str(round(backup["size"] / 1024)) + "G",
-                backup["type"],
-                backup["comment"],
+                backup["status"],
             ]
         )
     table.print()
@@ -2134,22 +2136,16 @@ def print_backup(response: object):
         [
             "ID",
             "DISK",
-            "STATUS",
             "CREATED",
-            "SIZE",
-            "TYPE",
-            "COMMENT",
+            "STATUS",
         ]
     )
     table.row(
         [
             backup["id"],
             backup["name"],
-            backup["status"],
             backup["created_at"],
-            str(round(backup["size"] / 1024)) + "G",
-            backup["type"],
-            backup["comment"],
+            backup["status"],
         ]
     )
     table.print()
@@ -2199,7 +2195,9 @@ def server_backup_create(
 # ------------------------------------------------------------- #
 
 
-@backup.command("set-property", help="Change backup properties.")
+@backup.command(
+    "set-property", aliases=["set"], help="Change backup properties."
+)
 @options(GLOBAL_OPTIONS)
 @options(OUTPUT_FORMAT_OPTION)
 @click.option("--comment", type=str, default=None, help="Comment.")
@@ -2305,3 +2303,47 @@ def server_backup_unmount(config, profile, verbose, disk_id, backup_id):
         click.echo(server_id)
     else:
         fmt.printer(response)
+
+
+# ------------------------------------------------------------- #
+# $ twc server dash                                             #
+# ------------------------------------------------------------- #
+
+
+@server.command("dash", help="Open Cloud Server dashboard in web browser.")
+@options(GLOBAL_OPTIONS[:2])
+@click.option(
+    "--tab/--win",
+    default=True,
+    show_default=True,
+    help="Open in new tab or new window.",
+)
+@click.argument("server_id", type=int, required=True)
+def server_dash(tab, server_id):
+    url = f"{TWC_CP_URL}/servers/{server_id}"
+    if tab:
+        webbrowser.open_new_tab(url)
+    else:
+        webbrowser.open_new(url)
+
+
+# ------------------------------------------------------------- #
+# $ twc server vnc                                              #
+# ------------------------------------------------------------- #
+
+
+@server.command("vnc", help="Open Cloud Server web VNC console in browser.")
+@options(GLOBAL_OPTIONS[:2])
+@click.option(
+    "--tab/--win",
+    default=True,
+    show_default=True,
+    help="Open in new tab or new window.",
+)
+@click.argument("server_id", type=int, required=True)
+def server_vnc(tab, server_id):
+    url = f"{TWC_CP_URL}/servers/{server_id}/console"
+    if tab:
+        webbrowser.open_new_tab(url)
+    else:
+        webbrowser.open_new(url)
